@@ -215,6 +215,11 @@ typedef enum { /*< since=1.0 >*/
  * @QMI_NAS_ACTIVE_BAND_NR5G_259: NR5G Band 259. Since 1.32.
  * @QMI_NAS_ACTIVE_BAND_NR5G_260: NR5G Band 260. Since 1.32.
  * @QMI_NAS_ACTIVE_BAND_NR5G_261: NR5G Band 261. Since 1.32.
+ * @QMI_NAS_ACTIVE_BAND_NR5G_46: NR5G Band 46. Since 1.36
+ * @QMI_NAS_ACTIVE_BAND_NR5G_91: NR5G Band 91. Since 1.36
+ * @QMI_NAS_ACTIVE_BAND_NR5G_92: NR5G Band 92. Since 1.36
+ * @QMI_NAS_ACTIVE_BAND_NR5G_93: NR5G Band 93. Since 1.36
+ * @QMI_NAS_ACTIVE_BAND_NR5G_94: NR5G Band 94. Since 1.36
  *
  * Band classes.
  *
@@ -362,7 +367,12 @@ typedef enum { /*< since=1.0 >*/
     QMI_NAS_ACTIVE_BAND_NR5G_26 = 293,
     QMI_NAS_ACTIVE_BAND_NR5G_30 = 294,
     QMI_NAS_ACTIVE_BAND_NR5G_29 = 295,
-    QMI_NAS_ACTIVE_BAND_NR5G_53 = 296
+    QMI_NAS_ACTIVE_BAND_NR5G_53 = 296,
+    QMI_NAS_ACTIVE_BAND_NR5G_46 = 297,
+    QMI_NAS_ACTIVE_BAND_NR5G_91 = 298,
+    QMI_NAS_ACTIVE_BAND_NR5G_92 = 299,
+    QMI_NAS_ACTIVE_BAND_NR5G_93 = 300,
+    QMI_NAS_ACTIVE_BAND_NR5G_94 = 301,
 } QmiNasActiveBand;
 
 /**
@@ -1261,13 +1271,31 @@ typedef enum { /*< since=1.10 >*/
 
 /**
  * QmiNasDLBandwidth:
- * @QMI_NAS_DL_BANDWIDTH_1_4: 1.4 MHz
- * @QMI_NAS_DL_BANDWIDTH_3: 3 MHz
- * @QMI_NAS_DL_BANDWIDTH_5: 5 MHz
- * @QMI_NAS_DL_BANDWIDTH_10: 10 MHz
- * @QMI_NAS_DL_BANDWIDTH_15: 15 MHz
- * @QMI_NAS_DL_BANDWIDTH_20: 20 MHz
- * @QMI_NAS_DL_BANDWIDTH_INVALID: Invalid
+ * @QMI_NAS_DL_BANDWIDTH_1_4: LTE 1.4 MHz
+ * @QMI_NAS_DL_BANDWIDTH_3: LTE 3 MHz
+ * @QMI_NAS_DL_BANDWIDTH_5: LTE 5 MHz
+ * @QMI_NAS_DL_BANDWIDTH_10: LTE 10 MHz
+ * @QMI_NAS_DL_BANDWIDTH_15: LTE 15 MHz
+ * @QMI_NAS_DL_BANDWIDTH_20: LTE 20 MHz
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_5: 5G NR 5MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_10: 5G NR 10MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_15: 5G NR 15MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_20: 5G NR 20MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_25: 5G NR 25MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_30: 5G NR 30MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_40: 5G NR 40MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_50: 5G NR 50Mhz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_60: 5G NR 60MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_80: 5G NR 80MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_90: 5G NR 90MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_100: 5G NR 100MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_200: 5G NR 200MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_400: 5G NR 400MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_GSM_02: GSM 0.2MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_TDSCDMA_16: TD-SCDMA 1.6MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_WCDMA_5: WCDMA 5MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_WCDMA_10: WCDMA 10MHz. Since 1.36
+ * @QMI_NAS_DL_BANDWIDTH_5GNR_70: 5G NR 70MHz. Since 1.36
  * @QMI_NAS_DL_BANDWIDTH_UNKNOWN: Unknown
  *
  * DL Bandwidth.
@@ -1275,14 +1303,32 @@ typedef enum { /*< since=1.10 >*/
  * Since: 1.16
  */
 typedef enum { /*< since=1.16 >*/
-    QMI_NAS_DL_BANDWIDTH_1_4      = 0,
-    QMI_NAS_DL_BANDWIDTH_3        = 1,
-    QMI_NAS_DL_BANDWIDTH_5        = 2,
-    QMI_NAS_DL_BANDWIDTH_10       = 3,
-    QMI_NAS_DL_BANDWIDTH_15       = 4,
-    QMI_NAS_DL_BANDWIDTH_20       = 5,
-    QMI_NAS_DL_BANDWIDTH_INVALID  = 6,
-    QMI_NAS_DL_BANDWIDTH_UNKNOWN  = 0xFF
+    QMI_NAS_DL_BANDWIDTH_1_4        = 0,
+    QMI_NAS_DL_BANDWIDTH_3          = 1,
+    QMI_NAS_DL_BANDWIDTH_5          = 2,
+    QMI_NAS_DL_BANDWIDTH_10         = 3,
+    QMI_NAS_DL_BANDWIDTH_15         = 4,
+    QMI_NAS_DL_BANDWIDTH_20         = 5,
+    QMI_NAS_DL_BANDWIDTH_5GNR_5     = 6,
+    QMI_NAS_DL_BANDWIDTH_5GNR_10    = 7,
+    QMI_NAS_DL_BANDWIDTH_5GNR_15    = 8,
+    QMI_NAS_DL_BANDWIDTH_5GNR_20    = 9,
+    QMI_NAS_DL_BANDWIDTH_5GNR_25    = 10,
+    QMI_NAS_DL_BANDWIDTH_5GNR_30    = 11,
+    QMI_NAS_DL_BANDWIDTH_5GNR_40    = 12,
+    QMI_NAS_DL_BANDWIDTH_5GNR_50    = 13,
+    QMI_NAS_DL_BANDWIDTH_5GNR_60    = 14,
+    QMI_NAS_DL_BANDWIDTH_5GNR_80    = 15,
+    QMI_NAS_DL_BANDWIDTH_5GNR_90    = 16,
+    QMI_NAS_DL_BANDWIDTH_5GNR_100   = 17,
+    QMI_NAS_DL_BANDWIDTH_5GNR_200   = 18,
+    QMI_NAS_DL_BANDWIDTH_5GNR_400   = 19,
+    QMI_NAS_DL_BANDWIDTH_GSM_02     = 20,
+    QMI_NAS_DL_BANDWIDTH_TDSCDMA_16 = 21,
+    QMI_NAS_DL_BANDWIDTH_WCDMA_5    = 22,
+    QMI_NAS_DL_BANDWIDTH_WCDMA_10   = 23,
+    QMI_NAS_DL_BANDWIDTH_5GNR_70    = 24,
+    QMI_NAS_DL_BANDWIDTH_UNKNOWN    = 0xFF,
 } QmiNasDLBandwidth;
 
 /**
